<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
  <!ENTITY copy "&#169;">
  <!ENTITY nbsp "&#160;">
  <!ENTITY lk "/webcenter_page/user_lang_key">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:java="http://xml.apache.org/xslt/java" xmlns:Math="java.lang.Math" xmlns:XSLUtils="com.esko.webcenter.jsp.XSLUtils" xmlns:Lang="com.esko.webcenter.jsp.LanguageMgr" xmlns:Optimize="com.esko.webcenter.xsl.utils.XslTransformOptimizePostProcessing" exclude-result-prefixes="java Math Lang Optimize">

  <xsl:import href="framework.xsl"/>
  
  <!-- Global Variables -->
  <xsl:variable name="tableColumnSpace" select="6"/>
	
	<!--
    	Template for generating the details navigation menu - this in a third row
    	(e.g., for projects - Documents, General Info, Approvals, ...)
	-->
	<xsl:template name="detailsMenuLevel3">
		<xsl:param name="menu"/>
		<xsl:param name="selection"/>
		<xsl:param name="isEditable"/>
	        
		<xsl:for-each select="$menu/menuitem">
			<xsl:variable name="show">
				<xsl:call-template name="showMenuItem">
					<xsl:with-param name="isEditable" select="$isEditable"/>
				</xsl:call-template>
			</xsl:variable>
			
			<xsl:if test="$show='TRUE'">
				<xsl:variable name="tag_name" select="labeltag"/>
				
				<!-- menu item link display for non-selected items only -->
				<xsl:choose>
					<xsl:when test="name=$selection">
						<li class="active">
							<a>
								<xsl:choose>
									<xsl:when test="link">
											<xsl:attribute name="id">
												<xsl:value-of select="$tag_name" />
											</xsl:attribute>
											<xsl:if test="url">
												<xsl:call-template name="detailsHref"/>
											</xsl:if>
											<xsl:if test="javascript">
												<xsl:attribute name="href">javascript:<xsl:value-of select="javascript"/></xsl:attribute>
											</xsl:if>
											<!-- check whether the name is translated, if not, show the label as is. -->
											<xsl:value-of select="Lang:getStrFallback(&lk;,$tag_name,$tag_name)"/>
										
									</xsl:when>
									<xsl:otherwise>
										<xsl:attribute name="href">#</xsl:attribute>
										<!-- check whether the name is translated, if not, show the label as is. -->
										<xsl:value-of select="Lang:getStrFallback(&lk;,$tag_name,$tag_name)"/>
									</xsl:otherwise>
								</xsl:choose>
								<xsl:call-template name="numberDocsAndTasks"><xsl:with-param name="menuItem" select="."/><xsl:with-param name="autoHide" select="1"/></xsl:call-template>
							</a>
						</li>
					</xsl:when>
					<xsl:otherwise>
						<li>
							<a>
								<xsl:attribute name="id">
									<xsl:value-of select="$tag_name" />
								</xsl:attribute>
								<xsl:if test="url">
									<xsl:call-template name="detailsHref"/>
								</xsl:if>
								<xsl:if test="javascript">
									<xsl:attribute name="href">javascript:<xsl:value-of select="javascript"/></xsl:attribute>
								</xsl:if>
									<!-- check whether the name is translated, if not, show the label as is. -->
									<xsl:value-of select="Lang:getStrFallback(&lk;,$tag_name,$tag_name)"/>
									<xsl:call-template name="numberDocsAndTasks"><xsl:with-param name="menuItem" select="."/><xsl:with-param name="autoHide" select="0"/></xsl:call-template>
							</a>
						</li>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<!--
		Template that adds the number of document or tasks
	-->
	<xsl:template name="numberDocsAndTasks">
		<xsl:param name="menuItem"/>
		<xsl:param name="autoHide"/>
		
		<xsl:variable name="menuItemName" select="$menuItem/name" />
		
		<xsl:if test="($menuItemName = 'PROJDETAILSDOCS') and (count(/webcenter_page/total_documents) > 0)">
				&nbsp;<span class="badge"><xsl:value-of select="/webcenter_page/total_documents"/></span>
		</xsl:if>
		<xsl:if test="($menuItemName = 'PROJDETAILSWCTASKS' or $menuItemName = 'TEMPLATEDETAILSWCTASKS') and (count(/webcenter_page/total_tasks_in_project) > 0)">
			&nbsp;<span class="badge"><xsl:value-of select="/webcenter_page/total_tasks_in_project"/></span>
		</xsl:if>
		<xsl:if test="($menuItemName = 'PROJDETAILSTHREADS') and (count(/webcenter_page/total_discussions) > 0)">
			&nbsp;<span class="badge"><xsl:value-of select="/webcenter_page/total_discussions"/></span>
		</xsl:if>
		<xsl:if test="($menuItemName = 'DOCDETAILSTHREADS') and (count(/webcenter_page/total_discussions) > 0)">
			&nbsp;<span class="badge"><xsl:value-of select="/webcenter_page/total_discussions"/></span>
		</xsl:if>
		<xsl:if test="($menuItemName = 'PROJDETAILSBOM') and (count(/webcenter_page/total_bom) > 0)">
			&nbsp;<span class="badge"><xsl:value-of select="/webcenter_page/total_bom"/></span>
		</xsl:if>
		
		<xsl:if test="contains($menuItem/url, 'dosavedsearch.jsp') and $autoHide=0">
			&nbsp;<span class="badge" data-init="pages/menu/SearchResultsCountBadge" data-init-priority="-150">-</span>
		</xsl:if>

	</xsl:template>

  <!--
            Template that analyzes rules to see if any more menu entries will be displayed.
            This is kind of brute force... but anything else seems complicated.
            Returns 'True' if there are more.
  -->
  <xsl:template name="moreMenuItems">
    <xsl:param name="isEditable"/>
    
    <xsl:variable name="show">
      <xsl:call-template name="showMenuItem">
        <xsl:with-param name="isEditable" select="$isEditable"/>
      </xsl:call-template>
    </xsl:variable>
      
      <xsl:choose>
        <xsl:when test="$show='TRUE'"><xsl:value-of select="'TRUE'"/></xsl:when>
        <xsl:otherwise>
          <!-- Check the remaining menu items -->
          <xsl:for-each select="following-sibling::menuitem[position()=1]">            
            <xsl:call-template name="moreMenuItems">
              <xsl:with-param name="isEditable" select="$isEditable"/>
            </xsl:call-template>
          </xsl:for-each>
        </xsl:otherwise>
      </xsl:choose>
      
  </xsl:template>
  

  
 
  <!--
            FOR TESTING ONLY !!!
            NOTE: has to be re-written to mimic all the tests in the new showMenuItem template
  -->
  <xsl:template name="showMenuItemTestOld">
    <xsl:param name="isEditable"/>
    
    <xsl:variable name="menuitemname" select="name"/>
    <xsl:variable name="hasTaskManagementLicense" select="(/webcenter_page/has_task_management_license)"/>	
	
    <xsl:choose>
      <!-- Analyze optional flag -->
      <xsl:when test="optional">
		optional
        <xsl:variable name="moItem" select="key('menuOverrideItemKey', $menuitemname)"/>
        <xsl:if test="$moItem/@show='TRUE'">
          <xsl:value-of select="$moItem/@show"/>
        </xsl:if>
      </xsl:when>
      <!-- Analyze a special case of project security -->
      <xsl:when test="scope/project_managers">
        <xsl:if test="$isEditable='1'">
		  security
		  <!-- also analyze task management license (could be both ) -->
		  <xsl:choose>
		    <xsl:when test="license"> and license <xsl:if test="$hasTaskManagementLicense"><xsl:value-of select="'TRUE'"/></xsl:if></xsl:when>
		    <xsl:otherwise><xsl:value-of select="'TRUE'"/></xsl:otherwise>
		  </xsl:choose>
        </xsl:if>
      </xsl:when>
	  <!-- Analyze task management license -->
	  <xsl:when test="license">
		license
		<xsl:choose>
			<xsl:when test="$hasTaskManagementLicense">YES!!!<xsl:value-of select="'TRUE'"/></xsl:when>
			<xsl:otherwise>no!!!<xsl:value-of select="''"/></xsl:otherwise>
		</xsl:choose>
	  </xsl:when>
      <!-- Show menu in all other cases -->
      <xsl:otherwise>
		others
        <xsl:value-of select="'TRUE'"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
 
  	<!--
    	This template creates the 4th level of menu. It contains the doc type specific details submenu items.
    	For example, a graphic file might have an ink menu at this level.
	-->
	<xsl:template name="detailsMenuLevel4">
	    <xsl:variable name="menu" select="key('menuItemKey', @menuitemname)"/>
	    <xsl:variable name="selection" select="@selected"/>
		
	   	<xsl:for-each select="$menu/menuitem">
			<xsl:variable name="show">
				<xsl:call-template name="showMenuItem">
					<xsl:with-param name="isEditable" select="'1'"/>
				</xsl:call-template>
			</xsl:variable>
			
			<xsl:if test="$show='TRUE'">
				<xsl:variable name="tag_name" select="labeltag"/>
				<xsl:choose>
					<xsl:when test="name=$selection">
						<li class="active"><a href="#">
							<xsl:value-of select="Lang:getStrFallback(&lk;,$tag_name,$tag_name)"/>
						</a></li>
					</xsl:when>
					<xsl:otherwise>
						<li>
							<a>
								<xsl:if test="url">
									<xsl:call-template name="detailsHref"/>
								</xsl:if>
								<xsl:if test="javascript">
									<xsl:attribute name="href">javascript:<xsl:value-of select="javascript"/></xsl:attribute>
								</xsl:if>
								<xsl:value-of select="Lang:getStrFallback(&lk;,$tag_name,$tag_name)"/>
							</a>
						</li>
					</xsl:otherwise>
				</xsl:choose>				
			</xsl:if>
		</xsl:for-each>
		
	</xsl:template> 
	
	<!-- 
		Optimized row action menu...
		Restructure the html of the row action menu so that this does not need to happen in JavaScript.
		
		Doing all the DOM operations in JavaScript can be a big bottleneck.
	-->
	<xsl:template name="OptimizedRowActionMenu">
		<xsl:param name="content"/>
		
		<!-- The more section... Easier to make this in xsl than in Java. -->
		<xsl:variable name="moresection">
			<div class="dropdown more">
				<a class="btn btn-default dropdown-toggle morebutton" href="#" data-toggle="dropdown" title="Lang:getStrBundleFallback(&lk;,'ActionMenu', 'ACTIONMENU_MORE_ACTIONS', 'More...')">
					<i class="icon icon-WCR_Actions-More12"/><!-- <span class="moretext"/><span class="caret"/> -->
				</a>
				<ul class="dropdown-menu"></ul>
			</div>
		</xsl:variable>
		
		
		<!-- doing some XSL + Java magic here... -->
		<xsl:copy-of select="Optimize:PostProcessActionMenuHtml(&lk;, $content, $moresection)"/>
	</xsl:template>


  	<!--
    	This template to create properties for action menu item (<a> element).
    	Should be called with the relevant menu item as the current context element.    	
	-->
 	<xsl:template name="actionproperties">
 		<xsl:param name="menuitem" select="."/>
		<xsl:param name="label" select="Lang:getStr(&lk;,labeltag)"/>
		
		<xsl:if test="$menuitem/action/selection/min">
			<xsl:attribute name="data-require-selection-min"> <xsl:value-of select="$menuitem/action/selection/min"/></xsl:attribute>
		</xsl:if>
		<xsl:if test="$menuitem/action/selection/max">
			<xsl:attribute name="data-require-selection-max"> <xsl:value-of select="$menuitem/action/selection/max"/></xsl:attribute>
		</xsl:if>
		<xsl:if test="not($menuitem/action/renderingstyle/label_style)">
			<xsl:attribute name="data-icon">icon <xsl:value-of select="$menuitem/icon/icon_name"/>
				<xsl:if test="$menuitem/icon/icon_family">
					<xsl:value-of select="' '"/><xsl:value-of select="$menuitem/icon/icon_family"/>
				</xsl:if> 
			</xsl:attribute>
		</xsl:if>
		<xsl:if test="$menuitem/action/renderingstyle/icon_style">
			<xsl:attribute name="data-icon-only">1</xsl:attribute>
		</xsl:if>
		<xsl:if test="$menuitem/action/actionpriority">
			<xsl:attribute name="data-visibility"><xsl:value-of select="$menuitem/action/actionpriority"/></xsl:attribute>
		</xsl:if>
		<xsl:value-of select="$label"/>
	</xsl:template>
	
	<!--
		Characteristic based visibility of menu items in project details.
		Returns 'true' when this menu needs to be shown OR it has no visibility settings (and is shown by default).
		Otherwise 'false' is returned
	-->
	<xsl:template name="showProjectCharacteristicVisibility">
		<xsl:param name="charvisibility"/>
		
		<xsl:choose>
			<!-- when we are in a project & this menu item has characteristic visibility set -->
			<xsl:when test="/webcenter_page/project/characteristic_list and charvisibility">
				<xsl:choose>
					<!-- when the project contains the characteristic that we need -->
					<xsl:when test="/webcenter_page/project/characteristic_list/project_characteristic[deleted='0']/characteristic_id=charvisibility">
						<xsl:value-of select="'true'" />
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="'false'" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'true'" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

  	<!--
    	This template to create action menu item for a built-in function.
    	Should be called with the relevant menu item as the current context element.
    	
    	name is the <action><actiontype><builtin><builtin_name> element
    	label is overrideable label string; defaults to menu label tag lookup
    	href is the link target (server page or javascript)
    	action is the action identifier (used in Search Results)
    	jsonoptions is a sniplet with json (used in Search Results)
	-->
 	<xsl:template name="builtinaction">
 		<xsl:param name="menuitem" select="."/>
		<xsl:param name="name"/>
		<xsl:param name="label" select="Lang:getStr(&lk;,labeltag)"/>
		<xsl:param name="href" select=''/>
		<xsl:param name="onclick" select=''/>
		<xsl:param name="action" select=''/>
		<xsl:param name="jsonoptions" select=''/>

		<xsl:variable name="ActionClass">
			<xsl:text>action</xsl:text>
			<xsl:if test="count($menuitem/action/actionclass) &gt; 0"><xsl:text> </xsl:text><xsl:value-of select="$menuitem/action/actionclass"/></xsl:if>
		</xsl:variable>
		<xsl:if test="$menuitem/action/actiontype/builtin/builtin_name = $name">
			<xsl:variable name="show">
				<xsl:call-template name="showProjectCharacteristicVisibility">
					<xsl:with-param name="charvisibility" select="$menuitem/charvisibility"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:if test="$show = 'true'">
				<a class="{$ActionClass}" 
					data-name="{$name}">
					<xsl:if test="string-length($href) &gt; 0">
						<xsl:attribute name="href"><xsl:value-of select="$href"/></xsl:attribute>
					</xsl:if>
					<xsl:if test="string-length($onclick) &gt; 0">
						<xsl:attribute name="onclick">javascript:{<xsl:value-of select="$onclick"/>}</xsl:attribute>
					</xsl:if>
					<xsl:if test="string-length($action) &gt; 0">
						<xsl:attribute name="data-action"><xsl:value-of select="$action"/></xsl:attribute>
					</xsl:if>
					<xsl:if test="string-length($jsonoptions) &gt; 0">
						<xsl:attribute name="data-jsonoptions"><xsl:value-of select="$jsonoptions"/></xsl:attribute>
					</xsl:if>
				 	<xsl:call-template name="actionproperties">
				 		<xsl:with-param name="menuitem" select="$menuitem"/>
				 		<xsl:with-param name="label" select="$label"/>
				 	</xsl:call-template>
				</a>
			</xsl:if>
		</xsl:if>
	</xsl:template>  
 
 	<!-- 
 		Template to create action button of Create Task type
 	 -->
 	<xsl:template name="createtaskaction">
		<xsl:param name="projectId"/>
		<xsl:param name="docVersionId" select="''"/>
		<xsl:param name="itemidsel" select="''"/>
		<xsl:param name="tags" select="''"/>
		<xsl:param name="urlencodedpageurl" select="/webcenter_page/pageurl" />

		<xsl:if test="action/actiontype/create_task">
			<xsl:variable name="show">
				<xsl:call-template name="showtaggedaction">
					<xsl:with-param name="tags" select="$tags"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:if test="$show = 'true'">
				<xsl:variable name="show2">
					<xsl:call-template name="showProjectCharacteristicVisibility">
						<xsl:with-param name="charvisibility" select="charvisibility"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:if test="$show2 = 'true'">
					<xsl:variable name="taskTypeName"><xsl:value-of select="action/actiontype/create_task/tasktype_name"/></xsl:variable>
					<xsl:variable name="startTaskOption"><xsl:value-of select="action/actiontype/create_task/start_task_option"/></xsl:variable>
					<xsl:variable name="hiddenElements"><xsl:value-of select="action/actiontype/create_task/hidden_elements"/></xsl:variable>
					<xsl:variable name="executeOnCreate"><xsl:value-of select="action/actiontype/create_task/execute_on_create"/></xsl:variable>
					<!-- compose URL -->
					<xsl:variable name="hRef">projwctaskdetailsnew.jsp?projectID=<xsl:value-of select="$projectId"/>&amp;<xsl:call-template name="menuFileUrlParameter"/>
						<xsl:if test="string-length($taskTypeName) &gt; 0">&amp;tasktypename=<xsl:value-of select="XSLUtils:urlEncode($taskTypeName)"/></xsl:if>
						<xsl:if test="string-length($startTaskOption) &gt; 0">&amp;start=<xsl:value-of select="$startTaskOption"/></xsl:if>
						<xsl:if test="string-length($hiddenElements) &gt; 0">&amp;hide=<xsl:value-of select="$hiddenElements"/></xsl:if>
						<xsl:if test="string-length($executeOnCreate) &gt; 0">&amp;execute=<xsl:value-of select="$executeOnCreate"/></xsl:if>
						<xsl:if test="string-length($urlencodedpageurl) &gt; 0">&amp;source=<xsl:value-of select="$urlencodedpageurl"/></xsl:if>
					</xsl:variable>
					<a class="action" 
						data-name="{name}">
						<xsl:choose>
							<xsl:when test="string-length($itemidsel) &gt; 0">
								<!-- let GlobalActionHandler process the request to add selected documents -->
								<xsl:attribute name="data-action"><xsl:value-of select="'REDIRECT'"/></xsl:attribute>
								<xsl:attribute name="data-itemidsel"><xsl:value-of select="$itemidsel"/></xsl:attribute>
								<xsl:attribute name="data-itemidname"><xsl:value-of select="'docversionid'"/></xsl:attribute>
								<xsl:attribute name="data-url"><xsl:value-of select="$hRef"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:variable name="documentparam">
									<xsl:choose>
										<xsl:when test="string-length($docVersionId) &gt; 0">
											<xsl:value-of select="'&amp;docversionid='"/><xsl:value-of select="XSLUtils:urlEncode($docVersionId)"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="''"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<xsl:attribute name="href"><xsl:value-of select="$hRef"/><xsl:value-of select="$documentparam"/></xsl:attribute>
							</xsl:otherwise>
						</xsl:choose>
					 	<xsl:call-template name="actionproperties"/>
					</a>
				</xsl:if>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	
	<!--
		Template to create action button for "Select All"
		
		Note: this action is NOT mentioned in the menu xml and will always appear when used.
	 -->
	<xsl:template name="selectallaction">
		<a class="action" data-action="toggle-selection-table-all" data-icon="icon icon-WCR_Actions-SelectAll12" data-icon-only="1" data-visibility="1"><xsl:value-of select="Lang:getStr(&lk;,'SELECTALLALTTAG')"/></a>
	</xsl:template>  

 	<!-- 
 		Template to match elements of a comma separated list, tagList with a tag, tagItem
 		
 		will outout a string with a '1" if there is a match  		
 	 -->
	<xsl:template name="matchtags">
		<xsl:param name="tagList"/>
		<xsl:param name="tagItem"/>
		
		<xsl:choose>
			<xsl:when test="starts-with($tagList, ' ')">
				<xsl:call-template name="matchtags">
					<xsl:with-param name="tagList" select="substring-after($tagList, ' ')"/>
					<xsl:with-param name="tagItem" select="$tagItem"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="tag">
					<xsl:choose>
						<xsl:when test="contains($tagList, ' ,')"><xsl:value-of select="substring-before($tagList,' ,')"/></xsl:when>
						<xsl:when test="contains($tagList, ',')"><xsl:value-of select="substring-before($tagList,',')"/></xsl:when>
						<xsl:otherwise><xsl:value-of select="$tagList"/></xsl:otherwise>
					</xsl:choose>
				</xsl:variable>				
				<xsl:choose>
					<xsl:when test="$tag = $tagItem">1</xsl:when>
					<xsl:otherwise>
						<xsl:if test="contains($tagList, ',')">
							<xsl:call-template name="matchtags">
								<xsl:with-param name="tagList" select="substring-after($tagList, ',')"/>
								<xsl:with-param name="tagItem" select="$tagItem"/>
							</xsl:call-template>
						 </xsl:if>
					</xsl:otherwise>
				</xsl:choose>		
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

 	<!-- 
 		Template to determine if a tagged item should be shown 		
 	 -->
 	<xsl:template name="showtaggedaction">
		<xsl:param name="tags" select="''"/>
		
		<xsl:variable name="actiontag" select="action/tag"/>
		
		<xsl:choose>
			<!-- no tags in menu: show -->
	   		<xsl:when test="not(string-length($actiontag) > 0)"><xsl:value-of select="'true'"/></xsl:when>
			<!-- * in search setup or * as menu tag: show -->
	   		<xsl:when test="($tags = '*') or ($actiontag = '*')"><xsl:value-of select="'true'"/></xsl:when>
			<!-- tags in menu, tags in search setups: show if matching only -->
	   		<xsl:when test="(string-length($tags) > 0) and (string-length($actiontag) > 0)">
				<xsl:variable name="match">
					<xsl:call-template name="matchtags">
						<xsl:with-param name="tagList" select="$tags"/>
						<xsl:with-param name="tagItem" select="$actiontag"/>
					</xsl:call-template> 
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="contains($match, '1')"><xsl:value-of select="'true'"/></xsl:when>
					<xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<!-- otherwise don't show -->
			<xsl:otherwise><xsl:value-of select="'false'"/></xsl:otherwise>
		</xsl:choose>
	</xsl:template>

 	<!-- 
 		Template to create action button of Start Workflow type 		
 	 -->
 	<xsl:template name="startworkflowaction">
		<xsl:param name="itemidsel" select="''"/>
		<xsl:param name="itemidname" select="'docversionid'"/>
		<xsl:param name="tags" select="''"/>
		<xsl:param name="projectId" select="''"/>		
		<xsl:param name="docVersionId" select="''"/>

		<xsl:if test="action/actiontype/start_workflow">
<!-- DEBUG (<xsl:value-of select="action/tag"/>,<xsl:value-of select="$tags"/>,<xsl:value-of select="(string-length(action/tag) > 0)"/>,<xsl:value-of select="(string-length($tags) > 0)"/>)  -->
			<xsl:variable name="show">
				<xsl:call-template name="showtaggedaction">
					<xsl:with-param name="tags" select="$tags"/>
				</xsl:call-template>
			</xsl:variable>

			<xsl:if test="$show = 'true'">
				<xsl:variable name="show2">
					<xsl:call-template name="showProjectCharacteristicVisibility">
						<xsl:with-param name="charvisibility" select="charvisibility"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:if test="$show2 = 'true'">
					<xsl:variable name="taskTypeName"><xsl:value-of select="action/actiontype/start_workflow/tasktype_name"/></xsl:variable>
					<xsl:variable name="bundle">
						<xsl:choose>
							<xsl:when test="action/actiontype/start_workflow/bundle"><xsl:value-of select="action/actiontype/start_workflow/bundle"/></xsl:when>
							<xsl:otherwise><xsl:value-of select="'true'"/></xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="projectparam">
						<xsl:choose>
							<xsl:when test="string-length($projectId) &gt; 0">
								<xsl:value-of select="'&amp;projectid='"/><xsl:value-of select="XSLUtils:urlEncode($projectId)"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="''"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="documentparam">
						<xsl:choose>
							<xsl:when test="string-length($docVersionId) &gt; 0">
								<xsl:value-of select="'&amp;docversionid='"/><xsl:value-of select="XSLUtils:urlEncode($docVersionId)"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="''"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="hRef">CreateProjectTaskOnDocuments.jsp?bundle=<xsl:value-of select="$bundle"/>&amp;tasktypename=<xsl:value-of select="XSLUtils:urlEncode($taskTypeName)"/><xsl:value-of select="$projectparam"/><xsl:value-of select="$documentparam"/></xsl:variable> 
					<a class="action" 
						data-name="{name}"
						data-action="START_WORKFLOW"
						data-itemidsel="{$itemidsel}"
						data-itemidname="{$itemidname}">
						<xsl:attribute name="data-url"><xsl:value-of select="$hRef"/></xsl:attribute>
					 	<xsl:call-template name="actionproperties"/>
					</a>
				</xsl:if>
			</xsl:if>
		</xsl:if>
	</xsl:template>  

	<!-- 
 		Template to create action button of Javascript type
 	 -->
 	<xsl:template name="javascriptaction">
		<xsl:param name="itemidsel" select="''"/>
		<xsl:param name="projectId" select="''"/>		
		<xsl:param name="docVersionId" select="''"/>
		<xsl:param name="menuFile" select="/webcenter_page/menu_file"/>
		<xsl:param name="tags" select="''"/>

		<xsl:if test="action/actiontype/javascript">
			<xsl:variable name="show">
				<xsl:call-template name="showtaggedaction">
					<xsl:with-param name="tags" select="$tags"/>
				</xsl:call-template>
			</xsl:variable>
	
			<xsl:if test="$show = 'true'">
				<xsl:variable name="show2">
					<xsl:call-template name="showProjectCharacteristicVisibility">
						<xsl:with-param name="charvisibility" select="charvisibility"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:if test="$show2 = 'true'">
					<a class="action" 
						data-name="{name}"
						data-action="SCRIPT"
						data-script="{action/actiontype/javascript}">
						<xsl:if test="string-length($itemidsel) &gt; 0">
							<xsl:attribute name="data-itemidsel"><xsl:value-of select="$itemidsel"/></xsl:attribute>
						</xsl:if>
						<xsl:if test="string-length($projectId) &gt; 0">
							<xsl:attribute name="data-projectid"><xsl:value-of select="$projectId"/></xsl:attribute>
						</xsl:if>
						<xsl:if test="string-length($docVersionId) &gt; 0">
							<xsl:attribute name="data-docversionid"><xsl:value-of select="$docVersionId"/></xsl:attribute>
						</xsl:if>
						<xsl:if test="string-length($menuFile) &gt; 0">
							<xsl:attribute name="data-menufile"><xsl:value-of select="$menuFile"/></xsl:attribute>
						</xsl:if>
					 	<xsl:call-template name="actionproperties"/>
					</a>
				</xsl:if>
			</xsl:if>
		</xsl:if>
	</xsl:template>  

<!-- 
  
            template that adds width into the header
                        
--> <xsl:template name="AddLeftEmptyColumn">
	<!-- rowspan param should be big enough to all fields -->
	<!-- width param should be in the same range as a thumbnail -->		
<tr><td rowspan="5000" width="195"><img src="images/clearpixel.gif" width="1" height="1"/></td></tr> </xsl:template> 

<xsl:template name="detailsHref"/>

	<xsl:template name="sessionExpiredForm">
		<xsl:param name="urlwanted"/>
		<xsl:param name="sectionid"/>
		<div   id="sessionForm" style="display:none;">
		  	<form method="post" action="login.jsp" id="sessionexpiredform" name="sessionexpiredform">
					<input type="hidden" name="username" value="{/webcenter_page/loginuser}"/>
					<input type="hidden" name="urlwanted"  value="{$urlwanted}" />
					<input type="hidden" name="sectionid"  value="{$sectionid}" />
			</form>
		</div>
		
	</xsl:template>

	<xsl:template name="SelectDocumentTemplateDialog">
		<div style="display: none; background-color: #F7F7F7; border-collapse: collapse;
				border-bottom: 1px solid #dfdfdf;" id="documentTemplateDialog" title="{Lang:getStr(&lk;,'SELECTDOCTEMPLATE')}">
			<input type="hidden" name="selectedStandard"/>				
			<input type="hidden" id="documentCounter"/>				
			<input type="hidden" id="documentCharacteristic"/>
			<input type="hidden" id="documentCharacteristiclevel"/>

			<div class="wcr-table" style="margin-bottom: 0px;">

			<!--  optionally add characteristics filter, 2 levels only -->
			<xsl:if test="count(/webcenter_page/doc_template_char_id) = 1">
				<table id="pageBodyTableId" class="darktext_darklink_11">
			 		<tbody id="test">
			 			<tr align="left" nowrap="nowrap" id="characteristicfilterrow">
				 			<!-- first selector -->
			 				<td id="characteristicsfilter" valign="middle">
			 					<!-- first button -->
			 					<xsl:variable name="filterlabel"><xsl:value-of select = "/webcenter_page/doc_template_label"/></xsl:variable>
			 					<xsl:value-of select="Lang:getStrFallback(&lk;,$filterlabel,'SHOW')"/>:&nbsp;
			 					
								<select id="selectChar" onChange="docCharSelected(this);" level="1">
									<option >
											<xsl:attribute name="value"><xsl:value-of select="''"/></xsl:attribute>
											<xsl:value-of select="Lang:getStr(&lk;,'ALL')"/>													
									</option>
									<xsl:for-each select="//characteristic[path=/webcenter_page/doc_template_char_path]" >
											<option >
												<xsl:attribute name="value"><xsl:value-of select="@id"/></xsl:attribute>
												<xsl:value-of select="name"/>
											</option>										
									</xsl:for-each>
								
							 	</select>
							</td >
							
							<!-- second selector (will only be shown when there is a selection made in the first selector) -->
			 				<td class="darktext_darklink_bold_12" id="characteristicsfilter" valign="middle">
			 					&nbsp;
			 					<select id="selectChar2" onChange="docCharSelected(this);" level="2">									
								</select>
							</td>
							 	
							<td align="left" valign="middle">
							 	<!-- go button -->
							 	<input id="filterUsingChar" class="ui-state-default ui-corner-all" type="button" value="Go" onclick="refreshDocTemplateContent();"/>
			 				</td>
			 			</tr>
			 		</tbody>
				</table>
			</xsl:if>	
										
			<!-- number of files and filter -->
			<div class="wcr-table-filter">
				<div class="wcr-table-actions-row">
					<div class="col-xs-12 col-sm-9">
						<div class="input-group full-width add-padding-bottom">
							<!-- add free text filter also  -->
							<label class="input-group-addon" for="documentTemplateDialogFilter"><xsl:value-of select="Lang:getStr(&lk;,'FILTERPROMPT')"/></label>
							<input id="documentTemplateDialogFilter" onkeyup="ChangeDocumentTemplateDialogFilter(this);" class="form-control"/>
						</div>
					</div>
					<div class="col-xs-12 col-sm-3">
						<label style="margin-top: 5px;">
							<span class="add-spacing-right"><xsl:value-of select="Lang:getStr(&lk;,'PROJDETAILSTOTALDOCS_TAG')"/>:</span>
							<span id="nrDocuments"></span>
						</label>
					</div>
				</div>
			
			</div>
			
			<div class="wcr-table-section" style="border-bottom: 0px;">
			
			<table id="pageBodyTableId" class="table-full-width">
			 	<tbody id="documentTemplateDialogContent3">
				 	<tr>
				 		<td>
				 			<div id="documentTemplateDialogContent" style="background-color: #FFFFFF;"></div>
				 		</td>
				 	</tr>
				 	
			 		<tr id="documentTemplateDialogContentRow">
			 			<td id="documentTemplateDialogInfoMessage">
			 				<xsl:value-of select="Lang:getStr(&lk;,'LOADINGDOCTEMPLATE_PLEASEWAIT')"/>
			 			</td>
			 		</tr>
			 	</tbody>
			</table>
			
			</div>
			
			</div>
		</div>
  </xsl:template>	
  

<xsl:template name="scriptincsdoctypesettings">

	function createDocTypeSettingsDictionary(prefix, suffix,useAutoNaming,freeEditField,categoryID)
      {
			// create a new dictionnary and add the settings to the dict
			var gDocTypeSettings = new Array();
		
			gDocTypeSettings['prefix']	= prefix;	// put in the array for debug purposes 
			gDocTypeSettings['suffix']	= suffix;
			//gDocTypeSettings['project_autoname_option']	= project_autoname_option;
		
			gDocTypeSettings['Autoname On']	= useAutoNaming ;
			gDocTypeSettings['Autoname Edit Field']	= freeEditField ;
			gDocTypeSettings['categoryID'] 		= categoryID  ;
      
      		return gDocTypeSettings ;
      }

				 //initialize the various document type support
					 
					  docTypeLabels = new Array(
        "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'GRAPHICS')"/></xsl:call-template>",
        "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'PAGE_LIST')"/></xsl:call-template>",
        "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'ARTIOSCAD')"/></xsl:call-template>",
        "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'CAPE')"/></xsl:call-template>",
        "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'OTHER')"/></xsl:call-template>",
        "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'ZIP_ARCHIVE')"/></xsl:call-template>",
        "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'ZIPPED_COLLADA')"/></xsl:call-template>",
        "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'COLLADA')"/></xsl:call-template>",
	  	"<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'CHILIPACK')"/></xsl:call-template>",
	  	"<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,'TEXT_CONTENT')"/></xsl:call-template>");
	  	
					 
					  var curDocTypeName;
					  <xsl:for-each select="/webcenter_page/doc_type_list/doc_type">
						  var curDocUploadTypeID = '<xsl:value-of select="@id"/>';
						  if (curDocUploadTypeID != null &amp;&amp; curDocUploadTypeID.length &gt; 0)
						  {
						  	gEnabledDocTypeIDs.push(curDocUploadTypeID);
						  }  
					  </xsl:for-each>
					  
						//initialize 'Graphical File Extensions' list (data retrieved from the XML source)
	  var curFileExtValue;
	  
	  //add all the extensions into the list
	  <xsl:for-each select="/webcenter_page/graphic_files_extensions/extension">
		curFileExtValue = '<xsl:value-of select="current()"/>';
		if (curFileExtValue != null &amp;&amp; curFileExtValue.length &gt; 0)
		{
	  		gGraphicalFileExtList.push(curFileExtValue.toUpperCase());	
	  	}
	  </xsl:for-each>
	  
	  // add all the other known extensions to the list
	  <xsl:for-each select="/webcenter_page/upload_doc_types/doc_type_list/doc_type ">
	    
		var uploadHint = '<xsl:value-of select="upload_hint"/>';
		if (uploadHint != null &amp;&amp; uploadHint.length &gt; 0)
		{
			var docType = new Array(2) ;
			docType[0] =  '<xsl:value-of select="@id"/>';
			docType[1] =  '<xsl:value-of select="upload_hint"/>'; 
			docType[2] =  "<xsl:call-template name="escapequotationmark"><xsl:with-param name="string" select="Lang:getStr(&lk;,label_tag)"/></xsl:call-template>";
			
	  		gknownExtList.push(docType);	
	  	}
	  </xsl:for-each>
	  
	  //initialize the various document type support
	  var curDocTypeName;
	  <xsl:for-each select="/webcenter_page/upload_doc_types/doc_type_list/doc_type">
		  curDocUploadTypeID = '<xsl:value-of select="@id"/>';
		  if (curDocUploadTypeID != null &amp;&amp; curDocUploadTypeID.length &gt; 0)
		  {
		  	gEnabledDocTypeIDs.push(curDocUploadTypeID);
		  }  
	  </xsl:for-each>


		// Load the document type autonaming options
	  // 1. load the general settings - this code relies on the fact that we always have this portion in the xml, even when there is no autoname on system level defined
	  // 2. look at the project specific settings and overload the general settings when needed 
	  <xsl:choose>
		  <xsl:when test="count(/webcenter_page/doctype_autonaming_list/doctype_autonaming) > 0">

				  <xsl:for-each select="/webcenter_page/doctype_autonaming_list/doctype_autonaming">
				  		<xsl:variable name="systemDocTypeID"><xsl:value-of select="doctypeid"/></xsl:variable>	  
						
				 		var docTypeID = '<xsl:value-of select="$systemDocTypeID"/>';
						var system_autoname_option = '<xsl:value-of select="autoname_option"/>';
						var system_category_option = '<xsl:value-of select="category_option"/>';
			
						var system_categoryID = '<xsl:value-of select="category_id"/>';
						
						var prefix = '' ;
						var suffix = '' ;
						
					
						// load the project specific settings if existing
						var project_autoname_option = 	'<xsl:value-of select="/webcenter_page/project_doctype_settings/doctype_autonaming_list/doctype_autonaming[doctypeid = $systemDocTypeID]/autoname_option"/>';
						
						var useAutoNaming = false ;
						if ((project_autoname_option == null) || (project_autoname_option != null &amp;&amp; project_autoname_option == '2')) // meaning use the system default
						{
							if (system_autoname_option == '2') // there are system settings defined 
							{
								useAutoNaming = true ;
			
									// get  the system prefix value
								prefix = '<xsl:call-template name="encodesinglequotes"><xsl:with-param name="string" select="/webcenter_page/doctype_autonaming_list/doctype_autonaming[doctypeid = $systemDocTypeID]/autoname_prefix"/></xsl:call-template>';
								suffix = '<xsl:call-template name="encodesinglequotes"><xsl:with-param name="string" select="/webcenter_page/doctype_autonaming_list/doctype_autonaming[doctypeid = $systemDocTypeID]/autoname_suffix"/></xsl:call-template>';					
							}
						}
						else if (project_autoname_option != null &amp;&amp; project_autoname_option == '1') // meaning use the project settings
						{
								prefix = '<xsl:call-template name="encodesinglequotes"><xsl:with-param name="string" select="/webcenter_page/project_doctype_settings/doctype_autonaming_list/doctype_autonaming[doctypeid = $systemDocTypeID]/autoname_prefix"/></xsl:call-template>';
								suffix = '<xsl:call-template name="encodesinglequotes"><xsl:with-param name="string" select="/webcenter_page/project_doctype_settings/doctype_autonaming_list/doctype_autonaming[doctypeid = $systemDocTypeID]/autoname_suffix"/></xsl:call-template>';								
						}
						else if (project_autoname_option != null &amp;&amp; project_autoname_option == '0' ) // no autonaming
						{
							// nothing to be done
						}			
						
						// we have the prefix and suffix that we will use. Check whether the suffix contains the string 'editfield'
						var freeEditField = false ;
						if (prefix!=null &amp;&amp; prefix.length > 0 )
						{	
							useAutoNaming = true ;
							if (suffix != null &amp;&amp; suffix.toLowerCase().indexOf("editfield") !=-1)
								freeEditField = true ;				 
						}	
					
						// we need to do the same thing for the category option 
						var categoryID = '' ;
						var project_category_option = 	'<xsl:value-of select="/webcenter_page/project_doctype_settings/doctype_autonaming_list/doctype_autonaming[doctypeid = $systemDocTypeID]/category_option"/>';
						
						if ((project_category_option == null) || (project_category_option != null &amp;&amp; project_category_option == '2')) // meaning use the system default
						{
							if (system_category_option == '2') // there are system settings defined 
								categoryID = '<xsl:value-of select="/webcenter_page/doctype_autonaming_list/doctype_autonaming[doctypeid = $systemDocTypeID]//category_id"/>';
						}
						else if (project_category_option != null &amp;&amp; project_category_option == '1') // meaning use the project settings
						{
							categoryID = '<xsl:value-of select="/webcenter_page/project_doctype_settings/doctype_autonaming_list/doctype_autonaming[doctypeid = $systemDocTypeID]/category_id"/>';
						}
						else if (project_category_option != null &amp;&amp; project_category_option == '0' ) // no autonaming
						{
							// nothing to be done
						}			
						
						gDocTypeConfigs[docTypeID] = createDocTypeSettingsDictionary(prefix, suffix,useAutoNaming,freeEditField,categoryID);  
				  </xsl:for-each>
		  </xsl:when>
		  <xsl:otherwise> <!-- this is the situation where we have no system wide settings -->
				  <xsl:for-each select="/webcenter_page/project_doctype_settings/doctype_autonaming_list/doctype_autonaming">
				  		var docTypeID = '<xsl:value-of select="doctypeid"/>';
						var prefix = '' ;
						var suffix = '' ;
						var freeEditField = false ;
						var useAutoNaming = false ;
						
					  	<!-- get the autoname option -->
						var project_autoname_option = 	'<xsl:value-of select="autoname_option"/>';
						if (project_autoname_option !=null &amp;&amp; project_autoname_option == '1' ) // check whether there is a project specific doc type naming
						{
							prefix = '<xsl:call-template name="encodesinglequotes"><xsl:with-param name="string" select="autoname_prefix"/></xsl:call-template>';
							suffix = '<xsl:call-template name="encodesinglequotes"><xsl:with-param name="string" select="autoname_suffix"/></xsl:call-template>';	
						}	
						if (prefix!=null &amp;&amp; prefix.length > 0 )
						{	
							useAutoNaming = true ;
							if (suffix != null &amp;&amp; suffix.toLowerCase().indexOf("editfield") !=-1)
								freeEditField = true ;				 
						}	
							
					  	<!-- get the category option -->
						var project_category_option = 	'<xsl:value-of select="/webcenter_page/project_doctype_settings/doctype_autonaming_list/doctype_autonaming/category_option"/>';
						var categoryID = '';
						if (project_category_option!=null &amp;&amp; project_category_option == '1' ) // check whether there is a project specific att category
						{
							categoryID = '<xsl:value-of select="/webcenter_page/project_doctype_settings/doctype_autonaming_list/doctype_autonaming/category_id"/>';
						}
						gDocTypeConfigs[docTypeID] = createDocTypeSettingsDictionary(prefix, suffix,useAutoNaming,freeEditField,categoryID);
						
				  </xsl:for-each>
		  </xsl:otherwise>
	  </xsl:choose>

	  gDocTypeConfigUseCategory = true ;

</xsl:template>


<!-- Use this template for passing internationalization strings to java                      -->
<!-- keys should be a | separated list of keys that should be passed   (i.e. KEY1|KEY2|KEY3) -->
<!-- PREFIX:someText can be used to select all keys containing "someText"                  -->
<!-- By default language strings are available in JavaScript trough i18n.LANGUAGE_STRING     -->
<!-- with langVar another variable can be chosen to put the language strings in              -->
<!-- keys can be translated to another name in JS with , 	                                 -->
<!-- 	ORIGINAL_LANGUAGE_KEY,shortcut_in_js                                                 -->
<xsl:template name="i18n">
    <xsl:param name="keys" />
    <xsl:param name="nested" select="0" />
    <xsl:param name="langVar" select="'i18n'" />    
    
    
    <xsl:choose>
    	<xsl:when test="$nested = 0">
	    	<!-- begin javascript output -->
	    	<script type="text/javascript"><xsl:text disable-output-escaping="yes">&lt;!--</xsl:text>&#xA;
			var <xsl:value-of select="$langVar"/>;
			if (typeof <xsl:value-of select="$langVar"/> == "undefined" || <xsl:value-of select="$langVar"/> == null){
				<xsl:value-of select="$langVar"/> = {};
			}
			<xsl:call-template name="i18n">
				<xsl:with-param name="keys" select="$keys"/>
				<xsl:with-param name="nested" select="1" />
				<xsl:with-param name="langVar" select="$langVar"/>
			</xsl:call-template>
	    	
	    	<xsl:text disable-output-escaping="yes">//--&gt;&#xA;</xsl:text>&#xA;
			</script>	&#xA;
	    	<!--  end javascript output -->
    	</xsl:when>
    	
    	<xsl:otherwise>    	
	    	<xsl:variable name="newlist">
	    	<xsl:choose>
	    		<xsl:when test="contains($keys, '|')"><xsl:value-of select="normalize-space($keys)"/></xsl:when>
	    		<xsl:otherwise><xsl:value-of select="concat(normalize-space($keys), '|')"/></xsl:otherwise>
	    	</xsl:choose>
		    </xsl:variable>
		    <xsl:variable name="key" select="normalize-space(substring-before($newlist, '|'))" />
		    <xsl:variable name="remaining" select="substring-after($newlist, '|')" />	
    		<xsl:if test="string-length($key) > 0">
		    	<!-- process token -->
		    	<xsl:choose>
		    		<xsl:when test="contains($key, ',')">
		    			<xsl:variable name="realkey" select="normalize-space(substring-before($key, ','))" />
		    			<xsl:variable name="substitute" select="normalize-space(substring-after($key, ','))" />
		    			<xsl:value-of select="$langVar"/>['<xsl:value-of select="$substitute"/>'] = '<xsl:value-of select="XSLUtils:encodeForJScript(Lang:getStr(&lk;,$realkey))"/>';
		    		</xsl:when>
		    		<xsl:when test="starts-with($key,'PREFIX:')">
		    			<xsl:for-each select="Lang:getJSPStrsPrefix(&lk;, normalize-space(substring-after($key, ':')))">
		    				<xsl:value-of select="$langVar"/>['<xsl:value-of select="@key"/>'] = '<xsl:value-of select="XSLUtils:encodeForJScript(@value)"/>';
		    			</xsl:for-each>
		    		</xsl:when>
		    		<xsl:otherwise>
		    			<xsl:value-of select="$langVar"/>['<xsl:value-of select="$key"/>'] = '<xsl:value-of select="XSLUtils:encodeForJScript(Lang:getStr(&lk;,$key))"/>';
		    		</xsl:otherwise>
		    	</xsl:choose>		    	
		    </xsl:if>
		    <xsl:if test="string-length(normalize-space($remaining)) > 0">
		        <xsl:call-template name="i18n">
		            <xsl:with-param name="keys" select="$remaining" />
		            <xsl:with-param name="nested" select="1" />
		            <xsl:with-param name="langVar" select="$langVar"/>
		        </xsl:call-template>
		    </xsl:if>
    	</xsl:otherwise>
    </xsl:choose>
</xsl:template>

<!-- call this template, to include needed scripts/languagekeys for sDrop -->
<xsl:template name="sDropEnabler">
	<xsl:call-template name="i18n">
		<xsl:with-param name="keys" select="'PREFIX:SDROP_'"/>
		<xsl:with-param name="langVar" select="'gsDropI18N'"/>
	</xsl:call-template>
	
	<script type="text/javascript" src="javascript/mootools.js"></script>
	<script type="text/javascript" src="javascript/FilterUtils.js"></script>
	<script type="text/javascript" src="javascript/sdrop.js"></script>
</xsl:template>


<!-- call this template to get an inline help topic icon/popup -->
<xsl:template name="inlineHelp">
	<xsl:param name="topic" />
	<xsl:param name="padding" />
	<xsl:variable name="language" select="//user_lang_key"/>
	<xsl:variable name="url"  select="concat('help.jsp?topic=', $topic, '&amp;lang=', $language)" />
	
	
	<a>
		<xsl:if test="$padding ='false'">
			<xsl:attribute name="class"><xsl:value-of select="'inline_help-nopadding'"/></xsl:attribute>
		</xsl:if>
		<xsl:if test="$padding !='false'">
			<xsl:attribute name="class"><xsl:value-of select="'inline_help'"/></xsl:attribute>
		</xsl:if>
		<xsl:attribute name="href"><xsl:value-of select="$url" /></xsl:attribute>
		<xsl:attribute name="onclick">var pop = window.open('<xsl:value-of select="$url"/>', "help" ,"scrollbars=1, width=800 ,height=500, toolbar=yes, location=yes, menu=yes");pop.focus();return false;</xsl:attribute>
		<i class="icon icon-WCR_Info-Balloon icon-normal">
			<xsl:attribute name="title"><xsl:value-of select="Lang:getStr(&lk;,'HELP')"/></xsl:attribute>
		</i>		
	</a>
		
</xsl:template>

<!-- JS functionality that aids inserting 'WCR Help Framework' functionality via JavaScript -->
<!--  deprecated, use wcr-static/component/HelpIcon/HelpIcon -->
<xsl:template name="scriptincshelpfunctions">
<script type="text/javascript">&#xA;
	<xsl:text disable-output-escaping="yes">&lt;!--</xsl:text>&#xA;
		function GetHelpTopicIconLink(topic, userLang)
		{
			//prepare URL
			var URLval = 'help.jsp?topic='+topic+'&amp;lang='+userLang;
		
			//create the HTML String of the target Link
			//start with the initialization of the 'a'-begin element
			var HTMLval = '&lt;a class=&quot;inline_help&quot; ';
			//add 'href' attribute
			HTMLval = HTMLval + 'href=&quot;'+URLval+'&quot; ';
			//add onclick event handler (prepare it first to overcome the string delimiter hell)
			var onClickJS = &quot;var pop = window.open('&quot;+URLval+&quot;','help' ,'scrollbars=1, width=800 ,height=500, toolbar=yes, location=yes, menu=yes'); pop.focus(); return false;&quot;;
			HTMLval = HTMLval + 'onlick=&quot;'+onClickJS+'&quot; ';
			//close the A'-element-begin tag
			HTMLval = HTMLval + '&gt;';
		
			//append the enclosed IMG reference
			HTMLval = HTMLval + '&lt;img border=&quot;0&quot; src=&quot;images/help_icon_16.png&quot; style=&quot;padding-left: 4px;&quot; alt=&quot;<xsl:value-of select="XSLUtils:encodeForJScript(Lang:getStr(&lk;,'HELP'))"/>&quot; title=&quot;<xsl:value-of select="XSLUtils:encodeForJScript(Lang:getStr(&lk;,'HELP'))"/>&quot;  &gt;';
			//close the IMG element
			HTMLval = HTMLval + '&lt;/img&gt;';
			//close the A element
			HTMLval = HTMLval + '&lt;/a&gt;';
		
			return HTMLval; 
		}	
	<xsl:text disable-output-escaping="yes">//--&gt;</xsl:text>&#xA;
	</script>&#xA;    
</xsl:template>

<!-- call this template to get language tags in JS array 'langArrName' for Document Upload Config functionality -->
<xsl:template name="docUploadConfigJSLangTags">
	<xsl:param name="langArrName" select="'i18nLangArr'"/>
		// create object holding language strings and inject them using "i18n" template
		var <xsl:value-of select="$langArrName"/> = {};
	  <xsl:call-template name="i18n">
	   	<xsl:with-param name="nested" select="1"/>
	   	<xsl:with-param name="langVar" select="$langArrName"/>
	   	<xsl:with-param name="keys">
	   		<xsl:value-of select="'PREFIX:DocSrcHdl'"/>|
				TransHandlerTag|
				TransHandlerSimple|
				TransHandlerTranslated|
				PROJ_CREATION_MEMBER_BROWSE|
				PROJ_CREATION_MEMBER_LINK|
				UPLOAD_TAG|
				NEW_TAG|
				DOCDETAILSCOPY_TAG|
				ADD_DOCUMENTS_TO_BOM|
				MOVE|
				LOADINGINPROGRESS|
				CANCEL|
				TMPLTERR
	   	</xsl:with-param>
		</xsl:call-template>
</xsl:template>

<xsl:template name="outdatedbrowser_nojavascript_warning">
	<!-- Users with IE < 10 should get warning message -->
	<xsl:text disable-output-escaping="yes">&lt;!--[if lte IE 9]&gt;</xsl:text>
		<!-- inline styles, CSS might not be applied in IE <= 9 -->
		<div style="padding: 20px; margin:  20px; color: #a94442; border-color:  #ebccd1; background-color: #f2dede;" class="alert alert-warning">
			<h4><xsl:value-of select="Lang:getStr(&lk;,'OUTDATED_BROWSER_TITLE')" /></h4>
			<p><xsl:value-of select="Lang:getStr(&lk;,'OUTDATED_BROWSER_MSG')" /></p>
		</div>					
	<xsl:text disable-output-escaping="yes">&lt;![endif]--&gt;</xsl:text>
  
  	<!-- Warn that JavaScript should be enabled -->
  	<noscript>
  		<div class="alert alert-warning">
  			<h4><xsl:value-of select="Lang:getStr(&lk;,'JAVASCRIPT_DISABLED_TITLE')" /></h4>
  			<p><xsl:value-of select="Lang:getStr(&lk;,'JAVASCRIPT_DISABLED_MSG')" /></p>
  		</div>	   				
 	</noscript>
</xsl:template>

</xsl:stylesheet>
